﻿Ext.require('App.Const.Finances');
Ext.define('App.Control.Kivii.Finances.PolicyDetail.List', {
    extend: 'System.Control.EntityList',
    xtype: 'App.Control.Kivii.Finances.PolicyDetail.List',
    entityType: 'Kivii.Finances.Entities.PolicyDetail',
    // filter: {},
    // disabled:true,
    header: true,
    layout: 'fit',
    title: '目标客户',
    // iconCls: 'x-fa fa-cc',
    viewModel: {
        data: {
            _selection: null,
            lastOwnerKvid: null
        },
    },
    bind: {
        selection: '{_selection}'
    },
    store: {
        autoLoad: true,
        pageSize: 50,
        sorters: [{
            property: 'TargetName',
            direction: 'DESC'
        }]
    },
    plugins: [{
        ptype: 'cellediting',
        clicksToEdit: 0
    }],
    dockedItems: [{
        xtype: 'toolbar',
        dock: 'top',
        overflowHandler: 'scroller',
        items: [{
            xtype: 'searchField',
            flex: 1,
            minWidth: 250,
            labelWidth: 60,
            queryField: 'TargetName',
            emptyText: '模糊搜索公司名称'
        }, {
            text: '新增',
            iconCls: 'x-fa fa-plus',
            iconAlign: 'left',
            handler: '_onAddPolicyDetail',
        }, {
            text: '删除',
            iconCls: 'x-fa fa-trash-o',
            iconAlign: 'left',
            handler: '_onDeleteEntity',
            bind: {
                disabled: '{!_selection}'
            }
        }]
    }, {
        xtype: 'pagingtoolbar',
        dock: 'bottom',
        displayInfo: true,
        items: [{
            xtype: 'button',
            labelWidth: 60,
            iconCls: 'x-fa fa-check-square-o',
            bind: {
                text: '已选择{selectionCount}条记录,点击清除',
                hidden: '{selectionCount==0}'
            },
            handler: '_onClearSelections'
        }]
    }],
    columns: {
        defaults: {
            menuDisabled: true,
            sortable: true
        },
        items: [{
            xtype: 'rownumberer',
            align: 'center',
        }, {
            text: '目标客户',
            dataIndex: 'TargetName',
            minWidth: 180,
            flex: 1
        },{
            text: '创建人',
            dataIndex: 'CreatorName',
            width: 100
        }]
    },
    setOwner: function(_owner, _ctrl) {
        let _view = this;
        let _vm = _view.getViewModel();
        if (_view.filter === null) _view.setFilter({});
        _view.filter.PolicyKvid = _owner.Kvid;
        _vm.set('_owner', _owner);
        _view.reload();
    },
    controller: {
        _onClearSelections: function() {
            this.getView().clearSelections();
        },
        _onAddPolicyDetail: function(_ctrl) {
            let _controller = this;
            let _view = _controller.getView();
            let _vm = _controller.getViewModel();
            let _owner = _vm.data._owner;
            let _form = Ext.create('App.Control.Kivii.Finances.Policy.Customer.Selector', {
                header: false
            });
            let _win = Ext.create('Ext.window.Window', {
                layout: 'fit',
                title: _ctrl.text,
                iconCls: _ctrl.iconCls,
                iconAlign: 'left',
                autoScroll: true,
                width: 660,
                height: 380,
                modal: true,
                resizable: false,
                items: [_form]
            });
            _win.show();
            _form.on('entitySelected', function(_ctrl, _entities) {
                _win.close();
                let _items = [];
                for (let _i = 0; _i < _entities.length; _i++) {
                    let _selected = _entities[_i];
                    let _item = {};
                    _item.PolicyKvid = _owner.Kvid;
                    _item.BizId = _selected.FullName;
                    _item.BizKvid = _selected.Kvid;
                    _item.BizType = "Kivii.Customers.Entities.Customer";
                    _item.TargetName = _selected.FullName;
                    _item.TargetKvid = _selected.Kvid;
                    _items.push(_item);
                }
                Ext.Ajax.request({
                    url: '/Restful/' + _view.entityType + '/Create.json',
                    jsonData: {
                        Items: _items
                    },
                    success: function(_response) {
                        let _rtns = Ext.decode(_response.responseText);
                        Ext.toast('新增成功！');
                        _view.fireEvent('entityCreated', _controller, _rtns.Results[0]);
                        _view.reload();
                    },
                    failure: function(_response) {
                    }
                });
            });
        },
        _onDeleteEntity: function(_ctrl) {
            let _controller = this;
            let _view = _controller.getView();
            _view.deleteEntity();
        }
    }
});