﻿Ext.require('App.Const.Finances');
Ext.define('App.Control.Kivii.Finances.PolicyRecord.List', {
    extend: 'System.Control.EntityList',
    xtype: 'App.Control.Kivii.Finances.PolicyRecord.List',
    requires: ['App.Control.DownloadField'],
    entityType: 'Kivii.Finances.Entities.PolicyRecord',
    // filter: {},
    // disabled:true,
    header: true,
    layout: 'fit',
    title: '执行记录',
    // iconCls: 'x-fa fa-cc',
    viewModel: {
        data: {
            _selection: null,
            lastOwnerKvid: null
        },
    },
    bind: {
        selection: '{_selection}'
    },
    store: {
        autoLoad: true,
        pageSize: 800,
        sorters: [{
            property: 'OperateTime',
            direction: 'DESC'
        }]
    },
    plugins: [{
        ptype: 'cellediting',
        clicksToEdit: 0
    }],
    dockedItems: [{
        xtype: 'toolbar',
        dock: 'top',
        overflowHandler: 'scroller',
        items: [{
                xtype: 'datefield',
                fieldLabel: '业务日期 开始',
                format: 'Y-m-d',
                labelWidth: 90,
                reference: 'startTime',
                maxWidth: 220,
                editable: false,
                // readOnly:true,
                // minValue: '2019-10-01',
                // value: new Date(new Date().getFullYear(), new Date().getMonth(), 1),
                listeners: {
                    select: '_onSelectMonth'
                }
            },
            {
                xtype: 'datefield',
                fieldLabel: '结束',
                format: 'Y-m-d',
                labelWidth: 30,
                reference: 'endTime',
                maxWidth: 160,
                editable: false,
                // minValue: '2019-10-02',
                // value: new Date(new Date().getFullYear(), new Date().getMonth(), new Date().getDate()),
                listeners: {
                    select: '_onSelectMonth'
                }
            }, {
                xtype: 'searchField',
                flex: 1,
                minWidth: 250,
                labelWidth: 60,
                queryField: 'BizId,OperatorName,TargetName',
                emptyText: '模糊搜索业务编号、操作人、客户名称'
            }, {
            	xtype:'checkbox',
            	fieldLabel:'过滤作废',
            	labelWidth: 60,
            	handler:'_onCheck'
            },{
                xtype: 'downloadField',
                dataSource: '/Restful/Kivii.Finances.Entities.PolicyRecord/Query.xlsx', //数据源
                fileName: '数据导出',
                window: {
                    type: 'App.Control.Kivii.Finances.General.Template.Selector',
                    title: '选择模板',
                    iconCls: 'x-fa fa-file-excel-o',
                    autoScroll: true,
                    width: 700,
                    height: 350,
                    closeAction: 'hide',
                    modal: true,
                    layout: 'fit',
                    filter: {
                        FolderPath: '/Finances/Policy/Files',
                        TagsContains: 'PolicyRecord'
                    }
                }
            }
        ]
    }, {
        xtype: 'pagingtoolbar',
        dock: 'bottom',
        displayInfo: true,
        items: [{
            xtype: 'button',
            labelWidth: 60,
            iconCls: 'x-fa fa-check-square-o',
            bind: {
                text: '已选择{selectionCount}条记录,点击清除',
                hidden: '{selectionCount==0}'
            },
            handler: '_onClearSelections'
        }]
    }],
    columns: {
        defaults: {
            menuDisabled: true,
            sortable: true
        },
        items: [{
            xtype: 'rownumberer',
            align: 'center',
        }, {
            text: '业务编号',
            dataIndex: 'BizId',
            renderer: '_renderBizId',
            width: 230
        }, {
            text: '客户名称',
            dataIndex: 'TargetName',
            width: 180
        }, {
            dataIndex: 'AmountPlan',
            text: '原金额',
            align: 'right',
            renderer: '_renderAmount',
            width: 90
        }, {
            dataIndex: 'AmountOrigin',
            text: '原折后额',
            align: 'right',
            renderer: '_renderAmount',
            width: 100
        }, {
            dataIndex: 'AmountPolicy',
            text: '减免金额',
            align: 'right',
            renderer: '_renderAmount',
            width: 100
        }, {
            dataIndex: 'Amount',
            text: '合计金额',
            align: 'right',
            renderer: '_renderAmount',
            width: 100
        }, {
            text: '业务日期',
            dataIndex: 'OperateTime',
            width: 100,
            renderer: Ext.util.Format.dateRenderer('Y-m-d')
        }, {
            text: '操作人',
            dataIndex: 'OperatorName',
            width: 90
        }, {
            text: '备注',
            dataIndex: 'Remark',
            minWidth: 180,
            flex: 1
        }]
    },
    setOwner: function(_owner, _ctrl) {
        let _view = this;
        let _vm = _view.getViewModel();
        if (_view.filter === null) _view.setFilter({});
        _view.filter.PolicyKvid = _owner.Kvid;
        _vm.set('_owner', _owner);
        _view.reload();
    },
    controller: {
        _onClearSelections: function() {
            this.getView().clearSelections();
        },
        _renderBizId: function(_value, _meta, _record, _rowIndex) {
            if (_record.data.hasOwnProperty("OffsetKvid")) {
                if(_record.data.Amount>=0){
                	_meta.style = 'background-color:#FFA500';
            		return _value + "(已作废)";
                }
                _meta.style = 'background-color:#FFB5C5';
                return _value + "(作废冲账)";
            }
            return _value;
        },
        _renderAmount: function(_value, _meta, _record, _rowIndex) {
            return "￥ "+parseFloat(_value).toFixed(2);
        },
        _onCheck:function(_ctrl,_checked){
        	let _controller=this;
        	let _view=_controller.getView();
        	if (_view.filter === null) return;
        	if(_checked)_view.filter.OffsetKvid="00000000-0000-0000-0000-000000000000";
        	else delete _view.filter.OffsetKvid;
        	_view.reload();
        },
        _onSelectMonth: function(_ctrl, _time, _eOpts) {
            var _me = this;
            var _view = _me.getView();
            var _refs = _me.getReferences();
            var _startTime = _refs.startTime.value;
            var _endTime = _refs.endTime.value || new Date();
            if (_startTime > _endTime) {
                Ext.toast("开始日期不能大于结束日期!");
                return;
            }
            if (_view.filter === null) _view.setFilter({});
            delete _view.filter.OperateTimeGreaterThanOrEqualTo;
            delete _view.filter.OperateTimeLessThan;
            if (_startTime !== null) _view.filter.OperateTimeGreaterThanOrEqualTo = new Date(_startTime.getFullYear(), _startTime.getMonth(), _startTime.getDate());
            _view.filter.OperateTimeLessThan = new Date(_endTime.getFullYear(), _endTime.getMonth(), _endTime.getDate() + 1);
            _view.reload();
        }
    }
});